@@ -23,7 +23,7 @@ char *allocstr();
 void cuerror();
 void cumsg();
 
-int nmprintf();
+int nmprintf(char *, ...);
 
 FILE *efopen();
 
