@@ -10,24 +10,21 @@
 **	formatted (printf-style) write to stderr.
 */
 #include <stdio.h>
-#include <varargs.h>
+#include <stdarg.h>
 void exit();
 
 /*VARARGS*/
-void cuerror(va_alist)
-va_dcl
+void cuerror(char *fmt, ...)
 {
     va_list         args;
     int             r;
-    char           *fmt;
     extern char    *progname;
 
     if (progname != NULL)
 	if (fprintf(stderr, "%s: ", progname) < 0)
 	    exit(7);
-    va_start(args);
+    va_start(args, fmt);
     r = va_arg(args, int);
-    fmt = va_arg(args, char *);
     (void) vfprintf(stderr, fmt, args);	/* use vfprintf, not just fprintf */
     va_end(args);
     exit(r);
