@@ -11,20 +11,18 @@
 **	prepending progname, if it is available.
 */
 #include <stdio.h>
-#include <varargs.h>
+#include <stdarg.h>
 
 /*VARARGS*/
-void cumsg(va_alist)
-va_dcl
+void cumsg(char *fmt, ...)
 {
     va_list         args;
-    char           *fmt;
     extern char    *progname;
 
     if (progname != NULL)
 	if (fprintf(stderr, "%s: ", progname) < 0)
 	    exit(7);
-    va_start(args);
+    va_start(args, fmt);
     fmt = va_arg(args, char *);
     (void) vfprintf(stderr, fmt, args);	/* use vfprintf, not just fprintf */
     va_end(args);
