@@ -7,9 +7,7 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/errno.h>
-
-extern int errno;
+#include <errno.h>
 
 /*	This is a quick little utility that I wrote to 
 	check a FILE pointer to see if it is pointing
