@@ -12,20 +12,17 @@
 */
 #include <cu.h>
 #include <stdio.h>
-#include <varargs.h>
+#include <stdarg.h>
 
 /*VARARGS*/
-int nmprintf(va_alist)
-va_dcl
+int nmprintf(char *filename, ...)
 {
     va_list         args;
-    char           *filename;
     FILE           *f;
     char           *fmt;
     int             r;
 
-    va_start(args);
-    filename = va_arg(args, char *);
+    va_start(args, filename);
     fmt = va_arg(args, char *);
     if ((f = fopen(filename, "a")) == NULL)
 	cuerror(1, "nmprintf: couldn't open %s.\n", filename);
