@@ -194,7 +194,7 @@
 /* - removed 10/24/01 (confused the itanium compiler) - Joe M. Wade
 */
 #ifdef SUNSYSTEM
-#include <varargs.h>
+#include <stdarg.h>
 #endif
 
 #ifdef _NO_PROTO
