@@ -127,7 +127,7 @@ char *filename;
 /***********************************************************************/
 
 
-#include <varargs.h>
+#include <stdarg.h>
 #include <malloc.h>
 #define new_node(type)    ((type *) malloc( sizeof( type ) ))
 typedef struct linklist {
@@ -135,27 +135,31 @@ typedef struct linklist {
    struct linklist   *next;
 } Linklist, *Linklistptr;
 
-static char *concat( va_alist )
-              va_dcl
+static char *concat( char *s1, ... )
 {
    va_list       args;
    Linklistptr   firstlink = NULL, link, nextlink;
    char          *s;
    int           sum = 0;
 
-   va_start( args );
 
-   while ( (s = va_arg( args, char * )) )  {
-      if( !firstlink )  /* first link */
-         link = firstlink = new_node( Linklist );
-      else  {
-         link->next = new_node( Linklist );  /* attach previous link */
-         link = link->next;
-      }
-      link->s = s;
-      link->next = NULL;
-      sum += strlen( s );
-   }
+   if (s1 != NULL) {
+
+     va_start( args, s1 );
+     s = s1;
+     link = firstlink = new_node( Linklist );
+     link->s = s;
+     link->next = NULL;
+     sum += strlen( s );
+
+     while ( (s = va_arg( args, char * )) )  {
+       link->next = new_node( Linklist );  /* attach previous link */
+       link = link->next;
+       link->s = s;
+       link->next = NULL;
+       sum += strlen( s );
+       }
+     }
 
    if( sum > 0 )  {
       s = (char *) calloc( 1, sum + 1 );  /* zero fill new string space */
@@ -200,7 +204,6 @@ static XmString str_array_to_xmstr(cs, n)
 
 
 
-#include <varargs.h>
 static XmStringTable create_string_table( count, list ) 
         int             count;
         char            *list[];
@@ -356,7 +359,7 @@ Boolean found;
                  filename = concat(filename, Whats_Next_Filename, NULL);
            else {
                  i = 0; found = False;
-                 while(listitems[i][0] != (int)NULL){
+                 while(listitems[i][0] != (char)NULL){
                        if(strcmp(test,&listitems[i][0]) == 0) { 
                           filename = concat(filename, &listitems[i+1][0], NULL);
                           found = True;
@@ -611,10 +614,12 @@ fprintf(stderr,"Widget selected was %s (%08x)\n",XtName(This_Widget),This_Widget
     while ( (This_Widget != NULL) &&
      (XtHasCallbacks(This_Widget, XmNhelpCallback) != XtCallbackHasSome)) {
 	This_Widget = XtParent(This_Widget);
+/*
 	if ((debug_mode != 0) && (This_Widget != NULL)) {
 	  fprintf(stderr,"checking widget ancestor %s (%08x)\n",
 		XtName(This_Widget),This_Widget);
 	  }
+*/
 	}
 
     if(This_Widget != NULL)XtCallCallbacks(This_Widget, XmNhelpCallback, NULL);
