@@ -5,41 +5,71 @@
  ***********************************************************************/
  
 #include <stdio.h>
+#include <stdlib.h>
+#include <localsys.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
 
+#ifdef FTN_TO_C_UNDERSCORE_SUFFIX
 #define DISK_IT  disk_it_
 #define DISK_WR  disk_wr_
 #define DISK_RD  disk_rd_
 #define DISK_RWIN  disk_rwn_
 #define DISK_WWIN  disk_wwn_
 #define DISK_DL  disk_dl_
+#endif
 
-        int ifdes;
+#ifdef FTN_TO_C_UPPERCASE
+#define DISK_IT  DISK_IT
+#define DISK_WR  DISK_WR
+#define DISK_RD  DISK_RD
+#define DISK_RWIN  DISK_RWN
+#define DISK_WWIN  DISK_WWN
+#define DISK_DL  DISK_DL
+#endif
 
-int DISK_IT( int *nsamp,int *nbufsize,float *buf, int *nchars, char *dirct, int *ipid )
+#ifdef FTN_TO_C_NAME_COMPATABILITY
+#define DISK_IT  disk_it
+#define DISK_WR  disk_wr
+#define DISK_RD  disk_rd
+#define DISK_RWIN  disk_rwn
+#define DISK_WWIN  disk_wwn
+#define DISK_DL  disk_dl
+#endif
+
+        static int ifdes;
+
+#ifdef CRAYSYSTEM
+#include <fortran.h>
+int DISK_IT( int *nsamp,int *nbufsize,float *buf, int *nchars, _fcd *fdirct, int *ipid )
+#else
+int DISK_IT( int *nsamp,int *nbufsize,float *buf, int *nchars, char *dirct, int *ipid, int dirct_flen )
+#endif
 {
-        int disk_it(int nsamp,int nbufsize,float *buf, int nchars, char *dirct, int ipid);
+        int disk_it_c(int nsamp,int nbufsize,float *buf, int nchars, char *dirct, int ipid);
         int xnsamp;
         int xnchars;
         int xnbufsize;
 	int xipid;
         int i;
+#ifdef CRAYSYSTEM
+	char *dirct = _fcdtocp(fdirct);
+#endif
 
         xnsamp = *nsamp;
         xnchars = *nchars;
         xnbufsize = *nbufsize;
 	xipid = *ipid;
-        i = disk_it(xnsamp, xnbufsize, buf,xnchars, dirct, xipid );
+        i = disk_it_c(xnsamp, xnbufsize, buf,xnchars, dirct, xipid );
  
         return i;
 }
 
 int DISK_WR( int *nsamp,int *index,float *buf )
 {
-        int  disk_wrte(int nsamp,int index,float *buf);
+        int  disk_wrte_c(int nsamp,int index,float *buf);
         int xnsamp;
         int xindex;
         int i;
@@ -47,14 +77,14 @@ int DISK_WR( int *nsamp,int *index,float *buf )
         xnsamp = *nsamp;
         xindex = *index;
 
-        i = disk_wrte(xnsamp, xindex, buf );
+        i = disk_wrte_c(xnsamp, xindex, buf );
  
         return i;
 }
 
 int DISK_WWIN( int *nsamp,int *index, int *isamp, int *nsmp, float *buf )
 {
-        int  disk_wwin(int nsamp,int index,int isamp, int nsmp, float *buf);
+        int  disk_wwin_c(int nsamp,int index,int isamp, int nsmp, float *buf);
         int xnsamp;
         int xindex;
 	int xisamp;
@@ -66,14 +96,14 @@ int DISK_WWIN( int *nsamp,int *index, int *isamp, int *nsmp, float *buf )
 	xisamp = *isamp;
 	xnsmp  = *nsmp;
 
-        i = disk_wwin(xnsamp, xindex, xisamp, xnsmp, buf );
+        i = disk_wwin_c(xnsamp, xindex, xisamp, xnsmp, buf );
  
         return i;
 }
 
 int DISK_RD( int *nsamp,int *index,float *buf )
 {
-        int  disk_reed(int nsamp,int index,float *buf);
+        int  disk_reed_c(int nsamp,int index,float *buf);
         int xnsamp;
         int xindex;
         int i;
@@ -81,14 +111,14 @@ int DISK_RD( int *nsamp,int *index,float *buf )
         xnsamp = *nsamp;
         xindex = *index;
 
-        i = disk_reed(xnsamp, xindex, buf );
+        i = disk_reed_c(xnsamp, xindex, buf );
  
         return i;
 }
 
 int DISK_RWIN( int *nsamp,int *index,int *isamp, int *nsmp, float *buf )
 {
-        int  disk_rwin(int nsamp,int index,int isamp, int nsmp, float *buf);
+        int  disk_rwin_c(int nsamp,int index,int isamp, int nsmp, float *buf);
         int xnsamp;
         int xindex;
 	int xisamp;
@@ -100,7 +130,7 @@ int DISK_RWIN( int *nsamp,int *index,int *isamp, int *nsmp, float *buf )
 	xisamp = *isamp;
 	xnsmp  = *nsmp;
 
-        i = disk_rwin(xnsamp, xindex, xisamp, xnsmp, buf );
+        i = disk_rwin_c(xnsamp, xindex, xisamp, xnsmp, buf );
  
         return i;
 }
@@ -109,7 +139,7 @@ int DISK_DL( )
 {
         int i;
 
-        i = disk_dlte();
+        i = disk_dlte_c();
  
         return i;
 }
@@ -122,7 +152,7 @@ static int FileOpen = 0;
 #include <time.h>
  
 /* initialize the disk buffer  */
-        int disk_it(int nsamp,int nbufsize,float *buf,int nchars, char *dirct, int ipid)
+        int disk_it_c(int nsamp,int nbufsize,float *buf,int nchars, char *dirct, int ipid)
 {
 
         int n;
@@ -144,20 +174,20 @@ static int FileOpen = 0;
         strcat(FileName,"/fxydeconjunk");
         strcat(FileName,cn);
 
-        printf("Output work file is %s\n",FileName);
+        fprintf(stderr,"Output work file is %s\n",FileName);
 
  
 	/*        if((fout = fopen(FileName,"w+b"))==NULL) { */
 	ifdes = open( FileName, O_RDWR | O_CREAT ) ;
 	if (ifdes < 0) {
-                printf("Cannot open output file!\n");
-		printf(" ifdes is %d\n ",ifdes);
+                fprintf(stderr,"Cannot open output file!\n");
+		fprintf(stderr," ifdes is %d\n ",ifdes);
+		perror("FXYDECON: ");
                 exit(1);
                 }
         FileOpen = -1;
 	/*    printf(" Work unit number = %d \n", ifdes ); */
 
-       sislgbuf(ifdes, "off");
 
 
 /* do not bother to format the disk --- not needed for unit ---
@@ -166,13 +196,13 @@ static int FileOpen = 0;
         for(i=0;i<nbufsize;i++) {
                 actual = fwrite(buf, nbytes, ST_ONE, fout);
                    if ( actual != ST_ONE) {
-                     printf("Error in fwrite during format\n");
-                     printf("Requested index=%d\n",i);
-                     printf("Requested Number of records=%d\n",ST_ONE);
-                     printf("Actual Number of records wrote=%d\n",actual);
+                     fprintf(stderr,"Error in fwrite during format\n");
+                     fprintf(stderr,"Requested index=%d\n",i);
+                     fprintf(stderr,"Requested Number of records=%d\n",ST_ONE);
+                     fprintf(stderr,"Actual Number of records wrote=%d\n",actual);
     
                        if((remove(FileName))!= 0) {
-                         printf("Cannot remove output file!\n");
+                         fprintf(stderr,"Cannot remove output file!\n");
                          exit(1);
                          }
    
@@ -192,7 +222,7 @@ static int FileOpen = 0;
     
 	/*    printf("Unlinking output file\n");  */
                        if((unlink(FileName))!= 0) {
-                         printf("Cannot unlink output file!\n");
+                         fprintf(stderr,"Cannot unlink output file!\n");
                          exit(1);
                          }
         /*      printf("Unlinking of output file successful\n"); */
@@ -202,7 +232,7 @@ static int FileOpen = 0;
 }
 
 /* write to the disk buffer  */
-        int  disk_wrte(int nsamp,int index,float *buf)
+        int  disk_wrte_c(int nsamp,int index,float *buf)
 {
         unsigned int nbytes;
 	int nby, ndone ;
@@ -224,11 +254,11 @@ static int FileOpen = 0;
 	/* perror("LSEEK-a"); */
 
 	if ( (double)ierr < (double) 0) {
-	  printf("Error in lseek a\n");
-	  printf(" ierr= %g\n", (double)ierr);
-	  printf(" ipos = %g \n", (double) ipos );
-	  printf(" nsamplf = %g \n",  nsamplf);
-	  printf(" indexf = %g \n",  indexf );
+	  fprintf(stderr,"Error in lseek a\n");
+	  fprintf(stderr," ierr= %g\n", (double)ierr);
+	  fprintf(stderr," ipos = %g \n", (double) ipos );
+	  fprintf(stderr," nsamplf = %g \n",  nsamplf);
+	  fprintf(stderr," indexf = %g \n",  indexf );
 	  exit(1);
 	}
 
@@ -237,24 +267,26 @@ static int FileOpen = 0;
 
         ndone = write( ifdes, buf, nbytes) ;
            if ( ndone != nby ) {
-             printf("Error in write a\n");
-             printf("Requested index=%d\n",index);
-             printf("Requested Number of bytes=%u\n",nbytes);
-             printf("Actual Number of bytes written=%d\n",ndone);
-             printf("Unit number = %d \n", ifdes );
-	     printf(" ipos = %g\n",(double)ipos);
-	     printf(" index = %d \n",index);
-	     printf(" nsamp= %d \n",nsamp);
+             fprintf(stderr,"Error in write a\n");
+             fprintf(stderr,"Requested index=%d\n",index);
+             fprintf(stderr,"Requested Number of bytes=%u\n",nbytes);
+             fprintf(stderr,"Actual Number of bytes written=%d\n",ndone);
+             fprintf(stderr,"Unit number = %d \n", ifdes );
+	     fprintf(stderr," ipos = %g\n",(double)ipos);
+	     fprintf(stderr," index = %d \n",index);
+	     fprintf(stderr," nsamp= %d \n",nsamp);
              exit(1);
            }
 
+	fsync(ifdes);
+
         return 0;
 }
 
 
 
 /* write to the disk buffer for a window  */
-        int  disk_wwin(int nsamp,int index, int isamp, int nsmp ,float *buf)
+        int  disk_wwin_c(int nsamp,int index, int isamp, int nsmp ,float *buf)
 {
 
         unsigned int nbytes;
@@ -274,11 +306,11 @@ static int FileOpen = 0;
 	ierr = lseek( ifdes, ipos, SEEK_SET);
 
 	if ( (double)ierr < (double) 0) {
-	  printf("Error in lseek b\n");
-	  printf(" ierr= %g\n", (double)ierr);
-	  printf(" ipos = %g \n", (double) ipos );
-	  printf(" nsamplf = %g \n",  nsamplf);
-	  printf(" indexf = %g \n",  indexf );
+	  fprintf(stderr,"Error in lseek b\n");
+	  fprintf(stderr," ierr= %g\n", (double)ierr);
+	  fprintf(stderr," ipos = %g \n", (double) ipos );
+	  fprintf(stderr," nsamplf = %g \n",  nsamplf);
+	  fprintf(stderr," indexf = %g \n",  indexf );
 	  exit(1);
 	}
 
@@ -287,24 +319,25 @@ static int FileOpen = 0;
 
         ndone = write( ifdes, buf, nbytes) ;
            if ( ndone != nby ) {
-             printf("Error in disk_wwin \n");
-             printf("Requested index=%d\n",index);
-             printf("Requested Number of bytes=%u\n",nbytes);
-             printf("Actual Number of bytes written=%d\n",ndone);
-             printf("Unit number = %d \n", ifdes );
-	     printf(" ipos = %g\n",(double)ipos);
-	     printf(" index = %d \n",index);
-	     printf(" nsamp= %d \n",nsamp);
+             fprintf(stderr,"Error in disk_wwin \n");
+             fprintf(stderr,"Requested index=%d\n",index);
+             fprintf(stderr,"Requested Number of bytes=%u\n",nbytes);
+             fprintf(stderr,"Actual Number of bytes written=%d\n",ndone);
+             fprintf(stderr,"Unit number = %d \n", ifdes );
+	     fprintf(stderr," ipos = %g\n",(double)ipos);
+	     fprintf(stderr," index = %d \n",index);
+	     fprintf(stderr," nsamp= %d \n",nsamp);
              exit(1);
            }
 
+	fsync(ifdes);
 
         return 0;
 }
 
 
 /* read from the disk buffer  */
-        int  disk_reed(int nsamp,int index,float *buf)
+        int  disk_reed_c(int nsamp,int index,float *buf)
 {
         unsigned int nbytes;
 	int nby, ndone ;
@@ -320,11 +353,11 @@ static int FileOpen = 0;
 
 	ierr = lseek( ifdes, ipos, SEEK_SET);
 	if ( (double)ierr < (double) 0) {
-	  printf("Error in lseek a\n");
-	  printf(" ierr= %g\n", (double)ierr);
-	  printf(" ipos = %g \n", (double) ipos );
-	  printf(" nsamplf = %g \n",  nsamplf);
-	  printf(" indexf = %g \n",  indexf );
+	  fprintf(stderr,"Error in lseek a\n");
+	  fprintf(stderr," ierr= %g\n", (double)ierr);
+	  fprintf(stderr," ipos = %g \n", (double) ipos );
+	  fprintf(stderr," nsamplf = %g \n",  nsamplf);
+	  fprintf(stderr," indexf = %g \n",  indexf );
 	  exit(1);
 	}
 
@@ -334,14 +367,14 @@ static int FileOpen = 0;
 
 	ndone = read(ifdes, buf, nbytes);
            if ( ndone != nby ) {
-             printf("Error in read a\n");
-             printf("Requested index=%d\n",index);
-             printf("Requested Number of bytes=%u\n",nbytes);
-             printf("Actual Number of bytes read=%d\n",ndone);
-             printf("Unit number = %d \n", ifdes );
-	     printf(" ipos = %g\n",(double)ipos);
-	     printf(" index = %d \n",index);
-	     printf(" nsamp= %d \n",nsamp);
+             fprintf(stderr,"Error in read a\n");
+             fprintf(stderr,"Requested index=%d\n",index);
+             fprintf(stderr,"Requested Number of bytes=%u\n",nbytes);
+             fprintf(stderr,"Actual Number of bytes read=%d\n",ndone);
+             fprintf(stderr,"Unit number = %d \n", ifdes );
+	     fprintf(stderr," ipos = %g\n",(double)ipos);
+	     fprintf(stderr," index = %d \n",index);
+	     fprintf(stderr," nsamp= %d \n",nsamp);
              exit(1);
            }
 
@@ -352,7 +385,7 @@ static int FileOpen = 0;
 
 
 /* read from the disk buffer for a window  */
-        int  disk_rwin(int nsamp,int index, int isamp, int nsmp, float *buf)
+        int  disk_rwin_c(int nsamp,int index, int isamp, int nsmp, float *buf)
 {
         unsigned int nbytes;
 	int nby, ndone ;
@@ -374,11 +407,11 @@ static int FileOpen = 0;
 
 	ierr = lseek( ifdes, ipos, SEEK_SET);
 	if ( (double)ierr < (double) 0) {
-	  printf("Error in lseek a\n");
-	  printf(" ierr= %g\n", (double)ierr);
-	  printf(" ipos = %g \n", (double) ipos );
-	  printf(" nsamplf = %g \n",  nsamplf);
-	  printf(" indexf = %g \n",  indexf );
+	  fprintf(stderr,"Error in lseek a\n");
+	  fprintf(stderr," ierr= %g\n", (double)ierr);
+	  fprintf(stderr," ipos = %g \n", (double) ipos );
+	  fprintf(stderr," nsamplf = %g \n",  nsamplf);
+	  fprintf(stderr," indexf = %g \n",  indexf );
 	  exit(1);
 	}
 
@@ -387,14 +420,14 @@ static int FileOpen = 0;
 
 	ndone = read(ifdes, buf, nbytes);
            if ( ndone != nby ) {
-             printf("Error in disk_rwin\n");
-             printf("Requested index=%d\n",index);
-             printf("Requested Number of bytes=%u\n",nbytes);
-             printf("Actual Number of bytes read=%d\n",ndone);
-             printf("Unit number = %d \n", ifdes );
-	     printf(" ipos = %g\n",(double)ipos);
-	     printf(" index = %d \n",index);
-	     printf(" nsamp= %d \n",nsamp);
+             fprintf(stderr,"Error in disk_rwin\n");
+             fprintf(stderr,"Requested index=%d\n",index);
+             fprintf(stderr,"Requested Number of bytes=%u\n",nbytes);
+             fprintf(stderr,"Actual Number of bytes read=%d\n",ndone);
+             fprintf(stderr,"Unit number = %d \n", ifdes );
+	     fprintf(stderr," ipos = %g\n",(double)ipos);
+	     fprintf(stderr," index = %d \n",index);
+	     fprintf(stderr," nsamp= %d \n",nsamp);
              exit(1);
            }
 
@@ -406,7 +439,7 @@ static int FileOpen = 0;
 
 
 /* remove he disk buffer  */
-        int  disk_dlte(void)
+        int  disk_dlte_c(void)
 {
 
         if (FileOpen == 0) {
@@ -414,7 +447,7 @@ static int FileOpen = 0;
         }
 
         if((fclose(fout))==EOF) {
-                printf("Cannot close output file!\n");
+                fprintf(stderr,"Cannot close output file!\n");
                 exit(1);
                 }
  
@@ -423,7 +456,7 @@ static int FileOpen = 0;
    I has previously unlinked this input file, so I can no longer
    remove it.  It should disappear automatically.
         if((remove(FileName))!= 0) {
-                printf("Cannot remove output file!\n");
+                fprintf(stderr,"Cannot remove output file!\n");
                 exit(1);
                 }
 ------------------------------------------------------------------
