@@ -447,6 +447,7 @@ void main(argc,argv)
 	Display *dpy;
 	XtAppContext app_con;
 	Window top_window;
+	int depth;
 	unsigned int screen_number;
 	Widget shell,list_form;
 	Widget prev_widget,header;
@@ -602,13 +603,17 @@ void main(argc,argv)
 	shell = XtAppInitialize(&app_con,"Hlhedit",NULL,
 		0,&argc,argv,app_defs,NULL,0);
 
+	dpy   = XtDisplay(shell);
+	screen_number = DefaultScreen(dpy);
+	depth = DefaultDepth(dpy,screen_number);
+
 	arrow_pixmap = XCreatePixmapFromBitmapData (XtDisplay (shell),
 				RootWindowOfScreen (XtScreen (shell)),
 				(char *) arrow_bits,
 				arrow_width, arrow_height,
 				BlackPixelOfScreen (XtScreen (shell)),
 				WhitePixelOfScreen (XtScreen (shell)),
-				8);
+				depth);
 
 	outer_form = XtVaCreateManagedWidget("oform",
 		xmFormWidgetClass, shell,
