@@ -5,6 +5,7 @@
 #include <stdio.h>
 #include <localsys.h>
 #include <termios.h>
+#include <errno.h>
 /*
 #include <unistd.h>
 */
@@ -18,7 +19,6 @@
 #include <sys/ioctl.h>
 #endif
 
-extern int errno;
 extern char **environ;
 
 /* extern char *strcpy(), *strcat();*/ 
