@@ -19,7 +19,6 @@
 #include <netdb.h>
 void chkfds();
 #endif
-extern int errno;
 extern char **environ;
 
 /* extern char *strcpy(), *strcat(); */
@@ -173,6 +172,7 @@ ikpd_hostname()
 		ikpd_failure(IKP_PERMISSION);
 	if (buf_read(control, hostname, len) != len)
 		ikpd_failure(IKP_READ);
+	hostname[len] = '\0';
   
 /* this is a backdoor debugging mechanism. If the hostname in the remote
    process box is entered as "host:debug", turn on verbose mode if it is
@@ -850,15 +850,15 @@ ikpd_serversock()
 	streamsize = getenv("IKP_SOCKETSIZE");
 	if (streamsize != NULL) {
 	  sscanf(streamsize,"%d",&optval);
-          setsockopt(ioc->ioc_socket,SOL_SOCKET,SO_SNDBUF,&optval,sizeof(int));
-          setsockopt(ioc->ioc_socket,SOL_SOCKET,SO_RCVBUF,&optval,sizeof(int));
+          setsockopt(ioc->ioc_socket,SOL_SOCKET,SO_SNDBUF,(char *)&optval,sizeof(int));
+          setsockopt(ioc->ioc_socket,SOL_SOCKET,SO_RCVBUF,(char *)&optval,sizeof(int));
 	  }
 	if (verbose) {
 	  optval_length = sizeof(int);
-	  getsockopt(ioc->ioc_socket,SOL_SOCKET,SO_SNDBUF,&optval,&optval_length);
+	  getsockopt(ioc->ioc_socket,SOL_SOCKET,SO_SNDBUF,(char *)&optval,&optval_length);
 	  fprintf(errfp,"SO_SNDBUF = %d on socket %d\n",optval,ioc->ioc_socket);
 	  optval_length = sizeof(int);
-	  getsockopt(ioc->ioc_socket,SOL_SOCKET,SO_RCVBUF,&optval,&optval_length);
+	  getsockopt(ioc->ioc_socket,SOL_SOCKET,SO_RCVBUF,(char *)&optval,&optval_length);
 	  fprintf(errfp,"SO_RCVBUF = %d on socket %d\n",optval,ioc->ioc_socket);
 	  }
 	}
