@@ -12,7 +12,7 @@
 #include <size_defs.h>
 #include <header.h>
 #include <errno.h>
-#include <strings.h>
+#include <string.h>
 
 int verbose;
 FILE *prtfile;
