@@ -21,6 +21,7 @@
 */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <localsys.h>
 #include <fcntl.h>
 #include <cu_defs.h>
@@ -61,6 +62,7 @@ char * argv[];
 	char *hlh_entry,*buffer;
 	int C_ARGIS();
 	int is_a_pipe();
+	int read_to_eof;
  
 	union {
 		int size;
@@ -84,6 +86,7 @@ char * argv[];
 	  fprintf(stderr," (sequential)\n");
 	  fprintf(stderr," -ne[ne]\t(default=last)  : end trace #");
 	  fprintf(stderr," (sequential)\n");
+	  fprintf(stderr," -eof\t(default=off)   : read to end of data");
 	  fprintf(stderr," -V\t\t                : verbose output\n");
 	  fprintf(stderr," -H\t\t                : display HLH entries\n");
 	  fprintf(stderr," -h\t\t                : print this help\n");
@@ -97,6 +100,7 @@ char * argv[];
 	setbuf(stdout, NULL);
 
 	verbose = C_ARGIS("-V",&argc,argv);
+	read_to_eof = C_ARGIS("-eof",&argc,argv);
 
 	C_ARGSTR("-N",ntap," "," ",&argc,argv);
 	if (strncmp(ntap," ",1) != 0) {
@@ -346,7 +350,10 @@ char * argv[];
 	C_ARGI4("-ns",&start_trace,1,1,&argc,argv);
 	C_ARGI4("-ne",&end_trace,traces_per_record,traces_per_record,&argc,argv);
 	printf("starting record %d\n",start_rec);
-	printf("ending record %d\n",end_rec);
+	if (read_to_eof == 0)
+	  printf("ending record %d\n",end_rec);
+	else
+	  printf("ending record EOF\n");
 	printf("starting trace %d\n",start_trace);
 	printf("ending trace %d\n",end_trace);
 
@@ -385,6 +392,7 @@ char * argv[];
 		if (traces_to_skip != 0) {
 		  for (i=0,j=WORDSIZE-4; i<4; i++, j++) {
 		 	if ((c=getc(fdin)) == EOF) {
+		  	  printf("end of data found: ");
 		  	  printf("traces processed = %d\n",no_of_traces);
 			  exit(0);
 			  }
@@ -633,7 +641,7 @@ char * argv[];
 		  }
 
 		if (seq_trace == end_trace) {
-		  if (seq_rec == end_rec) {
+		  if ((seq_rec == end_rec) && ( read_to_eof == 0)) {
 		  	printf("traces processed = %d\n",no_of_traces);
 			exit(0);
 			}
