@@ -15,7 +15,7 @@ typedef enum {
 extern UfhStateType UfhState;
 
 char*	emalloc();
-void	execerror();
+void	execerror(char *f, ...);
 void	yyerror();
 
 extern char*	progname;
