@@ -732,31 +732,30 @@ need to check return codes ; we should also realloc after looking up indices
 	    fprintf(prtfile,"\n\n");
 	    }
 
+/* look up indexes to speed things up in trace loop */
+
 	C_SAVELU("TrcNumSmp",&TrcNumSmp_format,&TrcNumSmp_index,
 		&TrcNumSmp_length,SEGYTRACEHEADER);
 	C_SAVELU("TrcIdCode",&TrcIdCode_format,&TrcIdCode_index,
 		&TrcIdCode_length,SEGYTRACEHEADER);
-
-/* look up indexes to speed things up in trace loop */
-
-	C_SAVELU("RecNum", &RecNum_format, &RecNum_index, &RecNum_length,
-			TRACEHEADER);
-	C_SAVELU("TrcNum", &TrcNum_format, &TrcNum_index, &TrcNum_length,
-			TRACEHEADER);
-	C_SAVELU("SrPtXC", &SrPtXC_format, &SrPtXC_index, &SrPtXC_length,
-			TRACEHEADER);
-	C_SAVELU("SrPtYC", &SrPtYC_format, &SrPtYC_index, &SrPtYC_length,
-			TRACEHEADER);
-	C_SAVELU("RcPtXC", &RcPtXC_format, &RcPtXC_index, &RcPtXC_length,
-			TRACEHEADER);
-	C_SAVELU("RcPtYC", &RcPtYC_format, &RcPtYC_index, &RcPtYC_length,
-			TRACEHEADER);
-	C_SAVELU("DphInd", &DphInd_format, &DphInd_index, &DphInd_length,
-			TRACEHEADER);
-	C_SAVELU("PrRcNm", &PrRcNm_format, &PrRcNm_index, &PrRcNm_length,
-			TRACEHEADER);
-	C_SAVELU("PrTrNm", &PrTrNm_format, &PrTrNm_index, &PrTrNm_length,
-			TRACEHEADER);
+	C_SAVELU("RecNum", &RecNum_format, &RecNum_index,
+		&RecNum_length, TRACEHEADER);
+	C_SAVELU("TrcNum", &TrcNum_format, &TrcNum_index,
+		&TrcNum_length, TRACEHEADER);
+	C_SAVELU("SrPtXC", &SrPtXC_format, &SrPtXC_index,
+		&SrPtXC_length, TRACEHEADER);
+	C_SAVELU("SrPtYC", &SrPtYC_format, &SrPtYC_index,
+		&SrPtYC_length, TRACEHEADER);
+	C_SAVELU("RcPtXC", &RcPtXC_format, &RcPtXC_index,
+		&RcPtXC_length, TRACEHEADER);
+	C_SAVELU("RcPtYC", &RcPtYC_format, &RcPtYC_index,
+		&RcPtYC_length, TRACEHEADER);
+	C_SAVELU("DphInd", &DphInd_format, &DphInd_index,
+		&DphInd_length, TRACEHEADER);
+	C_SAVELU("PrRcNm", &PrRcNm_format, &PrRcNm_index,
+		&PrRcNm_length, TRACEHEADER);
+	C_SAVELU("PrTrNm", &PrTrNm_format, &PrTrNm_index,
+		&PrTrNm_length, TRACEHEADER);
 	C_SAVELU("SrcDepth", &SrcDepth_format, &SrcDepth_index,
 			&SrcDepth_length, SEGYTRACEHEADER);
 	C_SAVELU("FieldRecNum", &FieldRecNum_format, &FieldRecNum_index,
@@ -771,6 +770,14 @@ need to check return codes ; we should also realloc after looking up indices
 			&CdpNum_length, SEGYTRACEHEADER);
 	C_SAVELU("CdpTrcNum", &CdpTrcNum_format, &CdpTrcNum_index,
 			&CdpTrcNum_length, SEGYTRACEHEADER);
+/*
+   Set TrcNumSmp and TrcSmpInt to USP line header values as default
+*/
+	put_indexed_hw_val(header, TrcNumSmp_format, TrcNumSmp_index,
+		TrcNumSmp_length, SEGYTRACEHEADER, numsmp);
+
+	put_indexed_hw_val(header, TrcSmpInt_format, TrcSmpInt_index,
+		TrcSmpInt_length, SEGYTRACEHEADER, segysmpint);
 
 	trcknt = 0;
 
