@@ -124,7 +124,7 @@ char *filename;
 /***********************************************************************/
 
 
-#include <varargs.h>
+#include <stdarg.h>
 #include <malloc.h>
 #define new_node(type)    ((type *) malloc( sizeof( type ) ))
 typedef struct linklist {
@@ -132,27 +132,31 @@ typedef struct linklist {
    struct linklist   *next;
 } Linklist, *Linklistptr;
 
-static char *concat( va_alist )
-              va_dcl
+static char *concat( char *s1, ... )
 {
    va_list       args;
    Linklistptr   firstlink = NULL, link, nextlink;
    char          *s;
    int           sum = 0;
 
-   va_start( args );
 
-   while ( (s = va_arg( args, char * )) )  {
-      if( !firstlink )  /* first link */
-         link = firstlink = new_node( Linklist );
-      else  {
-         link->next = new_node( Linklist );  /* attach previous link */
-         link = link->next;
-      }
-      link->s = s;
-      link->next = NULL;
-      sum += strlen( s );
-   }
+   if (s1 != NULL) {
+
+     va_start( args, s1 );
+     s = s1;
+     link = firstlink = new_node( Linklist );
+     link->s = s;
+     link->next = NULL;
+     sum += strlen( s );
+
+     while ( (s = va_arg( args, char * )) )  {
+       link->next = new_node( Linklist );  /* attach previous link */
+       link = link->next;
+       link->s = s;
+       link->next = NULL;
+       sum += strlen( s );
+       }
+     }
 
    if( sum > 0 )  {
       s = (char *) calloc( 1, sum + 1 );  /* zero fill new string space */
@@ -197,7 +201,6 @@ static XmString str_array_to_xmstr(cs, n)
 
 
 
-#include <varargs.h>
 static XmStringTable create_string_table( count, list ) 
         int             count;
         char            *list[];
@@ -262,7 +265,8 @@ int OpenFile()
    file_string[file_length] = NULL;
 
    /* close up the file */
-   if (fclose(fp) != (int) NULL) fprintf(stderr, "Warning: unable to close file.\n");
+   if (fclose(fp) != (int)NULL)
+	fprintf(stderr, "Warning: unable to close file.\n");
 
    /* added the file string to the text widget */
    if(text)XmTextSetString(text, file_string);
@@ -271,6 +275,9 @@ int OpenFile()
    return(0);
 }
 
+
+
+
 XtCallbackProc
 Dismiss_Button(w, client, call)
 Widget w;
@@ -280,6 +287,11 @@ XtPointer call;
         XtDestroyWidget(XtParent(w));
 }
 
+
+
+
+
+
 XtCallbackProc
 Selection_Dismiss_Button(w, client, call)
 Widget w;
@@ -290,6 +302,10 @@ XtPointer call;
          selectionBox = (Widget)NULL;
 }
 
+
+
+
+
 void
 build_message(w, mess)
 Widget  w;
@@ -320,6 +336,9 @@ char  *mess;
     XtManageChild(mess_dialog);
 }
 
+
+
+
 XtCallbackProc
 sel_callback(w, client, call)
 Widget w;
@@ -338,7 +357,7 @@ Boolean found;
                  filename = concat(filename, Whats_Next_Filename, NULL);
            else {
                  i = 0; found = False;
-                 while(listitems[i][0] != (int)NULL){
+                 while(listitems[i][0] != (char)NULL){
                        if(strcmp(test,&listitems[i][0]) == 0) { 
                           filename = concat(filename, &listitems[i+1][0], NULL);
                           found = True;
@@ -355,6 +374,9 @@ Boolean found;
                           }
 }
 
+
+
+
 XtCallbackProc
 Help_Dismiss(w, client, call)
 Widget w;
@@ -369,6 +391,8 @@ XtPointer call;
         }
 }
 
+
+
 XtCallbackProc
 XuNo_More_Help(w, client, call)
 Widget w;
@@ -379,6 +403,10 @@ XtPointer call;
    build_message(w, message);
 }
 
+
+
+
+
 /*  create help window  */
 
 static Widget
@@ -426,6 +454,9 @@ Widget parent;
     return( retval );
 }
 
+
+
+
 XtCallbackProc
 XuHelp_On_Help(w, client, call)
 Widget w;
@@ -456,6 +487,10 @@ XtPointer call;
     XtManageChild(ver);
 }
 
+
+
+
+
 XtCallbackProc
 XuHelp_Index(w, client, call)
 Widget w;
@@ -468,7 +503,7 @@ XtPointer call;
     XmString    *xmstrTable[125];
 
 
-    if(selectionBox == NULL){
+    if(selectionBox == (Widget)NULL){
 
     argcnt = 0;
     XtSetArg(args[argcnt], XmNlistLabelString, (xmstr[0]=XmStringCreateLtoR(
@@ -512,6 +547,9 @@ XtPointer call;
 
 }
 
+
+
+
 XtCallbackProc
 XuHelper (w, client, call)
 Widget w;
@@ -544,6 +582,7 @@ char *filnam;
 
 }
 
+
 void
 XuDisplay_HelpText (helpinfo)
 unsigned char *helpinfo;
@@ -555,6 +594,9 @@ unsigned char *helpinfo;
                 }
 }
 
+
+
+
 XtCallbackProc
 XuHelp_On_Context(w, client, call)
 Widget w;
@@ -575,11 +617,20 @@ fprintf(stderr,"Widget selected was %s (%08x)\n",XtName(This_Widget),This_Widget
     while ( (This_Widget != NULL) &&
      (XtHasCallbacks(This_Widget, XmNhelpCallback) != XtCallbackHasSome)) {
 	This_Widget = XtParent(This_Widget);
+/*
+	if ((debug_mode != 0) && (This_Widget != NULL)) {
+	  fprintf(stderr,"checking widget ancestor %s (%08x)\n",
+		XtName(This_Widget),This_Widget);
+	  }
+*/
 	}
 
     if(This_Widget != NULL)XtCallCallbacks(This_Widget, XmNhelpCallback, NULL);
 }
 
+
+
+
 XtCallbackProc
 XuHelp_On_Version(w, client, call)
 Widget w;
