@@ -9,7 +9,7 @@
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/errno.h>
+#include <errno.h>
 #include <X11/Intrinsic.h>
 #include <X11/cursorfont.h>
 #include <X11/StringDefs.h>
@@ -36,7 +36,6 @@
 
 extern char *optarg;
 extern int optind, opterr;
-extern int errno;
 
 int chdc_pid,dd_pid;
 DriveDataInfo drive_info;
