@@ -654,25 +654,6 @@ void msg_message(char *text)
 */
 void window_title(char *buf, long id)
 {
-/*                             Argus fix...Zoom a flip rec 1,2 is still broken.  int tmp;
-
-  if (srec[id]>erec[id]) {
-    tmp=srec[id];
-    srec[id]=erec[id];
-    erec[id]=tmp;
-  }
-  if (strace[id]>etrace[id]) {
-    tmp=strace[id];
-    strace[id]=etrace[id];
-    etrace[id]=tmp;
-  }
-  if (ssamp[id]>esamp[id]) {
-    tmp=ssamp[id];
-    ssamp[id]=esamp[id];
-    esamp[id]=tmp;
-  }
-  */
-
   sprintf(buf,"%d Window: %d - %s %s - %s %d %d %d,%d %d %d,%d %d %d #%s#",
 	  xdisplay[id].sequence,id,xdisplay[id].time,xdisplay[id].date,
 	  xdisplay[id].filename,srec[id],erec[id],irec[id],strace[id],
@@ -681,8 +662,6 @@ void window_title(char *buf, long id)
 }
 
 
-
-
 void set_mode_label(int value, long id)
 {
   if (xdisplay[id].init!=-1) {
