@@ -7,7 +7,7 @@
  *	modified test version with gzip compression
  * 	(part of xsd.new) J. Ehlers 4/2/98
  */
-#include <malloc.h>
+/* #include <malloc.h> */
 #include <signal.h>
 #include <fcntl.h>
 #include <stdio.h>
