@@ -30,18 +30,12 @@ extern char printer_name[1024];
 
 static Widget text_print[7];
 static Widget toggle_color=NULL;
-/*
-static Widget toggle_tek=NULL;
-*/
 static Widget toggle_setting=NULL;
 static unsigned char *ras_print;
 static int print_width,print_height,border;
 static int print_min_x,print_min_y,print_max_x,print_max_y;
 static Boolean color_flag=True;
 static Boolean settings_flag=False;
-/*
-static Boolean tek_flag=False;
-*/
 static char title[1024]="",x_title[1024]="Trace #",z_title[1024]="Sample #";
 static char note_name[1024]="",filename[1024]="";
 
@@ -306,13 +300,6 @@ void printCB(Widget w, XtPointer client_data, XtPointer call_data)
   else
     color_flag=False;
   
-/*
-  if (XmToggleButtonGetState(toggle_tek))
-    tek_flag=True;
-  else
-    tek_flag=False;
-*/
-
   settings_flag=XmToggleButtonGetState(toggle_setting);
 
   save_print(message->id);
@@ -332,13 +319,12 @@ void save_print(long id)
   FILE *in;
   XColor color[256];
   struct rasterfile header;
-  struct rasterfile swap;
   unsigned char red[256],green[256],blue[256];
-/*
-  char *tek_header="Processing_options  -fd -r1 -Cd -Dd -Gd -Mc -Rd -Sd -#1\n";
-*/
   char buf2[1024],*tmp_file1;
   int n,out1,out2,old_mode,note_length,x,y;
+#ifdef LINUXSYSTEM
+  struct rasterfile swap;
+#endif
 
   tmp_file1=tmpnam(NULL);
   out1=open(tmp_file1,O_WRONLY|O_TRUNC|O_CREAT,0666);
@@ -356,20 +342,11 @@ void save_print(long id)
     return;
   }
 
-/*
-  if (tek_flag) {
-    write(out1,tek_header,strlen(tek_header));
-  }
-*/
-
   if (color_flag)
     print_width=xdisplay[id].image->width+2*border+125;
   else
     print_width=xdisplay[id].image->width+2*border;
 
-/* DWN need more room for header annotation
-  print_height=xdisplay[id].image->height+2*border;
-*/
   print_height=xdisplay[id].image->height+2*border+25;
   if (print_height<MIN_PRINT_HEIGHT+border+25)
     print_height=MIN_PRINT_HEIGHT+border+25;
@@ -742,7 +719,7 @@ void expose_labels(long id, char *buf, char *font_name,
 	if (XGetPixel(image,x1,y1)!=bg)
 	  *(ras_print+(x+y1)+((y+(width-x1))*print_width))=XGetPixel(image,x1,y1);
   } else {
-    int xstart,x2;
+    int xstart;
 
     /* DWN 1/15/97 label is wider than destination image */
     if (width>print_width) xstart=width-print_width;
