@@ -1,3 +1,8 @@
+/***********************************************************************
+ *                copyright 2001, Amoco Production Company             *
+ *                            All Rights Reserved                      *
+ *                    an affiliate of BP America Inc.                  *
+ ***********************************************************************/
 /*
    This routine is designed to look at a USP line header and return
    an array of character strings containing the historical line header 
@@ -5,6 +10,7 @@
    found.
 */
 #include <stdio.h>
+#include <stdlib.h>
 #include <localsys.h>
 #include <save_defs.h>
 #include <size_defs.h>
