@@ -114,8 +114,13 @@ void save_hlh(char *itr, int lbytes, int *lbyout)
 	hlh_bytes += new_byte_count + HLHINT;
 
 	byte_count--;
+#if ( BYTE_ORDER == BIG_ENDIAN )
 	memcpy(itr+position, (char *)(&byte_count) +
 		sizeof(byte_count) - HLHINT, HLHINT);
+#else
+	memcpy(itr+position, (char *)(&byte_count),
+		 HLHINT);
+#endif
 	memcpy(itr+position+HLHINT, outbuf, new_byte_count); 
 	free(outbuf);
 
