@@ -5,6 +5,7 @@
  ***********************************************************************/
 
 #include <mod_defs.h>
+#include <errno.h>
 
 #ifndef CRAYSYSTEM	/* do this for any machine other than the Crays */
 
@@ -23,7 +24,6 @@ int *i1err;      /* error flag */
 int *i1fd;       /* unix file descriptor */
 int *i1seek;     /* lseek byte position from beginning of file */
 {
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -40,7 +40,6 @@ int *s1buff;    /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -66,7 +65,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -91,7 +89,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    i1stat =  read(*i1fd, s1buff+(*m1buff), *i1bytes);
    if(i1stat == *i1bytes)
       *i1err = 0;
@@ -112,7 +109,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    i1stat = write(*i1fd, s1buff+(*m1buff), *i1bytes);
    if(i1stat == *i1bytes)
       *i1err = 0;
@@ -129,7 +125,6 @@ F_MODCL3 (i1err, i1fd)
 int *i1err;      /* error flag */
 int *i1fd;       /* unix file descriptor */
 {
-   extern int errno;
    /* close specified file */
    *i1err = close(*i1fd);
    if(*i1err != 0)
@@ -144,7 +139,6 @@ int *i1fd;       /* unix file descriptor */
 char *fn;        /* filename */
 int  len;        /* length of filename, fortran character variable */
 {
-   extern int errno;
    /* open specified file */
    /* file must not already exist, i.e. fortran status='new' */
    *i1fd = open(fn, O_RDWR+O_CREAT+O_EXCL, (int) 0660 );
@@ -161,7 +155,6 @@ int *i1fd;       /* unix file descriptor */
 char *fn;         /* filename */
 int  len;        /* length of filename, fortran character variable */
 {
-   extern int errno;
    /* open specified file */
    /* file must already exist, i.e. fortran status='old' */
    *i1fd = open(fn, O_RDWR, (int) 0660 );
@@ -197,7 +190,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -238,7 +230,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -287,7 +278,6 @@ int *i1err;      /* error flag */
 int *i1fd;       /* unix file descriptor */
 int *i1seek;     /* lseek byte position from beginning of file */
 {
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -304,7 +294,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -330,7 +319,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -355,7 +343,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    i1stat =  read(*i1fd, s1buff+(*m1buff), *i1bytes);
    if(i1stat == *i1bytes)
       *i1err = 0;
@@ -376,7 +363,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    i1stat = write(*i1fd, s1buff+(*m1buff), *i1bytes);
    if(i1stat == *i1bytes)
       *i1err = 0;
@@ -393,7 +379,6 @@ F_MODCL3 (i1err, i1fd)
 int *i1err;      /* error flag */
 int *i1fd;       /* unix file descriptor */
 {
-   extern int errno;
    /* close specified file */
    *i1err = close(*i1fd);
    /* printf(" modcl3_ fd=  %d  i1err=  %d \n", *i1fd, *i1err); */
@@ -406,7 +391,6 @@ _fcd fn;         /* filename */
 int  len;        /* length of filename, fortran character variable */
 {
    int  i1stat;
-   extern int errno;
    i1stat = unlink( _fcdtocp(fn));
    /* printf(" unlink_ i1stat=  %d  file= %s \n", i1stat, _fcdtocp(fn)); */
    if(i1stat == 0)
@@ -422,7 +406,6 @@ int *i1fd;       /* unix file descriptor */
 _fcd fn;         /* filename */
 int  len;        /* length of filename, fortran character variable */
 {
-   extern int errno;
    /* open specified file */
    /* file must not already exist, i.e. fortran status='new' */
    *i1fd = open(_fcdtocp(fn), O_RDWR+O_CREAT+O_BIG+O_EXCL+O_PLACE,
@@ -440,7 +423,6 @@ int *i1fd;       /* unix file descriptor */
 _fcd fn;         /* filename */
 int  len;        /* length of filename, fortran character variable */
 {
-   extern int errno;
    /* open specified file */
    /* file must already exist, i.e. fortran status='old' */
    *i1fd = open(_fcdtocp(fn), O_RDWR, (int) 0660 );
@@ -458,7 +440,6 @@ int *i1fd;       /* unix file descriptor */
 _fcd fn;         /* filename */
 int  len;        /* length of filename, fortran character variable */
 {
-   extern int errno;
    /* open specified file */
    /* file must not already exist, i.e. fortran status='new' */
    *i1fd = open(_fcdtocp(fn), O_RDWR+O_RAW+O_CREAT+O_BIG+O_EXCL+O_PLACE,
@@ -476,7 +457,6 @@ int *i1fd;       /* unix file descriptor */
 _fcd fn;         /* filename */
 int  len;        /* length of filename, fortran character variable */
 {
-   extern int errno;
    /* open specified file */
    /* file must already exist, i.e. fortran status='old' */
    *i1fd = open(_fcdtocp(fn), O_RDWR+O_RAW, (int) 0660 );
@@ -557,7 +537,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
@@ -597,7 +576,6 @@ int *s1buff;     /* i/o buffer */
 int *m1buff;	/* byte offset into s1buff */
 {
    int  i1stat;
-   extern int errno;
    if(lseek(*i1fd, (long)*i1seek, 0l) < 0)
       *i1err = -1;
    else
