@@ -125,7 +125,7 @@ char *filename;
 /***********************************************************************/
 
 
-#include <varargs.h>
+#include <stdarg.h>
 #include <malloc.h>
 #define new_node(type)    ((type *) malloc( sizeof( type ) ))
 typedef struct linklist {
@@ -133,27 +133,31 @@ typedef struct linklist {
    struct linklist   *next;
 } Linklist, *Linklistptr;
 
-static char *concat( va_alist )
-              va_dcl
+static char *concat( char *s1, ... )
 {
    va_list       args;
    Linklistptr   firstlink = NULL, link, nextlink;
    char          *s;
    int           sum = 0;
 
-   va_start( args );
 
-   while ( (s = va_arg( args, char * )) )  {
-      if( !firstlink )  /* first link */
-         link = firstlink = new_node( Linklist );
-      else  {
-         link->next = new_node( Linklist );  /* attach previous link */
-         link = link->next;
-      }
-      link->s = s;
-      link->next = NULL;
-      sum += strlen( s );
-   }
+   if (s1 != NULL) {
+
+     va_start( args, s1 );
+     s = s1;
+     link = firstlink = new_node( Linklist );
+     link->s = s;
+     link->next = NULL;
+     sum += strlen( s );
+
+     while ( (s = va_arg( args, char * )) )  {
+       link->next = new_node( Linklist );  /* attach previous link */
+       link = link->next;
+       link->s = s;
+       link->next = NULL;
+       sum += strlen( s );
+       }
+     }
 
    if( sum > 0 )  {
       s = (char *) calloc( 1, sum + 1 );  /* zero fill new string space */
@@ -198,7 +202,6 @@ static XmString str_array_to_xmstr(cs, n)
 
 
 
-#include <varargs.h>
 static XmStringTable create_string_table( count, list ) 
         int             count;
         char            *list[];
@@ -263,7 +266,8 @@ int OpenFile()
    file_string[file_length] = NULL;
 
    /* close up the file */
-   if (fclose(fp) != (int)NULL) fprintf(stderr, "Warning: unable to close file.\n");
+   if (fclose(fp) != (int)NULL)
+	fprintf(stderr, "Warning: unable to close file.\n");
 
    /* added the file string to the text widget */
    if(text)XmTextSetString(text, file_string);
@@ -381,7 +385,7 @@ Widget w;
 caddr_t client;
 caddr_t call;
 {
-        if(XtParent(w) != NULL){
+        if(XtParent(w) != (Widget)NULL){
             XtUnmanageChild(XtParent(w));
             XtDestroyWidget(XtParent(w));
             Help_Window = NULL;
@@ -504,7 +508,7 @@ caddr_t call;
     XmString    *xmstrTable[125];
 
 
-    if(selectionBox == NULL){
+    if(selectionBox == (Widget)NULL){
 
     argcnt = 0;
     XtSetArg(args[argcnt], XmNlistLabelString, (xmstr[0]=XmStringCreateLtoR(
