@@ -29,6 +29,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <math.h>
+#include <errno.h>
 #include "field.h"
 #include "global_defs.h"
 
@@ -105,8 +106,6 @@ extern char *trim(), *ljust(), *sp2undr(), *findval();
 extern int rtckfield();
 
 
-extern int errno;
-
 char *envfile = ".explenv";
 char *helpcmd = NULL;
 char filename[300];
